@@ -4,13 +4,13 @@ import re
 
 class CTkScrollableDropdown(customtkinter.CTkToplevel):
 
-    def __init__(self, attach, x=None, y=None, button_color=None, height: int = 55, width: int = None,
+    def __init__(self, attach, x=None, y=None, button_color=None, height: int = None, width: int = None,
                  fg_color=None, button_height: int = 20, justify="center", scrollbar_button_color=None,
                  scrollbar=True, scrollbar_button_hover_color=None, frame_border_width=0, values=[],
                  command=None, image_values=[], alpha: float = 0.95, frame_corner_radius=20, double_click=False,
-                 resize=False, frame_border_color=None, text_color=None, autocomplete=False,
+                 frame_border_color=None, text_color=None, autocomplete=False,
                  hover_color=None, pagination: bool = True, items_per_page: int = 50,
-                 groups=None, **button_kwargs):
+                 groups=None, font=("Segoe UI", 12), fade_in_duration: bool = True, fps: int = 60, **button_kwargs):
         super().__init__(master=attach.winfo_toplevel(), takefocus=1)
 
         self.group_patterns = None
@@ -37,18 +37,24 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         self.current_page = 0
         self.filtered_values = None
         self.current_group = 0
+        self.font = font
         self.groups = []
+        self.fade_enabled = fade_in_duration
+        self.fps = max(1, int(fps))
+        self.fade_animation_duration = 0.25
+        self.animating = False
+
         if groups is not None:
             for g in groups:
                 if isinstance(g, (list, tuple)) and len(g) >= 2:
                     self.groups.append({"name": g[0], "pattern": g[1]})
                 else:
                     raise ValueError(f"groups must be a list of [name, pattern], got {g!r}")
-        
+
         self.group_names = [g["name"] for g in self.groups]
         self.group_patterns = []
         included_values = set()
-        
+
         for g in self.groups:
             pattern = g["pattern"]
             if pattern == "__OTHERS__":
@@ -58,14 +64,14 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
                 self.group_patterns.append(compiled)
                 matched = [v for v in self.all_values if compiled.search(v)]
                 included_values.update(matched)
-        
+
         self.grouped_values = {}
         for i, pat in enumerate(self.group_patterns):
             if pat == "__OTHERS__":
                 self.grouped_values[i] = [v for v in self.all_values if v not in included_values]
             else:
                 self.grouped_values[i] = [v for v in self.all_values if pat.search(v)]
-        
+
         if sys.platform.startswith("win"):
             self.after(100, lambda: self.overrideredirect(True))
             self.transparent_color = self._apply_appearance_mode(self._fg_color) if hasattr(self, '_fg_color') else "#FFFFFF"
@@ -91,7 +97,7 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         self.scroll_button_color = customtkinter.ThemeManager.theme["CTkScrollbar"]["button_color"] if scrollbar_button_color is None else scrollbar_button_color
         self.scroll_hover_color = customtkinter.ThemeManager.theme["CTkScrollbar"]["button_hover_color"] if scrollbar_button_hover_color is None else scrollbar_button_hover_color
         self.frame_border_color = customtkinter.ThemeManager.theme["CTkFrame"]["border_color"] if frame_border_color is None else frame_border_color
-        self.button_color = customtkinter.ThemeManager.theme["CTkFrame"]["top_fg_color"] if button_color is None else button_color
+        self.button_color = customtkinter.ThemeManager.theme["CTkButton"]["fg_color"] if button_color is None else button_color
         self.text_color = customtkinter.ThemeManager.theme["CTkLabel"]["text_color"] if text_color is None else text_color
         self.hover_color = customtkinter.ThemeManager.theme["CTkButton"]["hover_color"] if hover_color is None else hover_color
         if not scrollbar:
@@ -101,15 +107,16 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
             self.search_var = customtkinter.StringVar()
             self.search_var.trace_add('write', lambda *args: self.live_update(self.search_var.get()))
             self.search_entry = customtkinter.CTkEntry(self, textvariable=self.search_var)
-            self.search_entry.pack(fill="x")
+            self.search_entry.pack(fill="x", pady=(0, 5))
         if self.groups:
-            self.group_frame = customtkinter.CTkFrame(self, fg_color=self.fg_color)
-            self.group_frame.pack(fill="x", padx=5)
+            self.group_frame = customtkinter.CTkFrame(self, fg_color=self.fg_color, bg_color=self.transparent_color)
+            self.group_frame.pack(fill="x", padx=5, pady=(0, 5))
             self.group_buttons = []
             for idx, name in enumerate(self.group_names):
                 btn = customtkinter.CTkButton(
                     self.group_frame,
                     text=name,
+                    font=self.font,
                     height=button_height,
                     fg_color=self.button_color,
                     text_color=self.text_color,
@@ -130,7 +137,7 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
             border_color=self.frame_border_color
         )
         self.frame._scrollbar.grid_configure(padx=3)
-        self.frame.pack(expand=True, fill="both")
+        self.frame.pack(expand=True, fill="both", pady=(3, 0))
         if self.pagination:
             self.button_container = customtkinter.CTkFrame(self.frame, fg_color=self.fg_color)
             self.button_container.pack(expand=True, fill="both")
@@ -139,12 +146,14 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         else:
             self.button_container = self.frame
         self.dummy_entry = customtkinter.CTkEntry(self.frame, fg_color="transparent", border_width=0, height=1, width=1)
-        self.height = height
-        self.height_new = height
+        self.is_height = bool(height)
+        if height is None:
+            self.height_new = attach.winfo_toplevel().winfo_height()
+        else:
+            self.height_new = height
         self.width = width
         self.command = command
         self.fade = False
-        self.resize = resize
         self.autocomplete = autocomplete
         self.var_update = customtkinter.StringVar()
         self.appear = True
@@ -155,7 +164,11 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         else:
             self.justify = "c"
         self.button_height = button_height
-        self.image_values = None if len(image_values) != len(self.values) else image_values
+        self.image_values = image_values
+        self.value_to_image = {}
+        if image_values and len(image_values) == len(values):
+            for val, img in zip(values, image_values):
+                self.value_to_image[val] = img
         self.resizable(width=False, height=False)
         self.transient(self.master)
         if double_click or isinstance(self.attach, customtkinter.CTkEntry) or isinstance(self.attach, customtkinter.CTkComboBox):
@@ -179,25 +192,42 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         if self.autocomplete:
             self.bind_autocomplete()
         self.withdraw()
-        self.attributes("-alpha", self.alpha)
+        self.attributes("-alpha", 0)
         if self.groups:
             self.switch_group(0)
         self._init_buttons()
 
     def _on_group_frame_configure(self, event):
+        if not self.group_buttons:
+            return
+
         min_btn_width = 100
-        cols = max(1, event.width // min_btn_width)
-    
-        for child in self.group_frame.grid_slaves():
-            child.grid_forget()
-    
+        n = len(self.group_buttons)
+        cols = max(1, min(n, event.width // min_btn_width))
+        rows = (n + cols - 1) // cols
+
+        frame_height = rows * self.button_height
+        if self.group_frame.winfo_height() != frame_height:
+            self.group_frame.configure(height=frame_height)
+
         for idx, btn in enumerate(self.group_buttons):
             row = idx // cols
-            col = idx % cols
-            btn.grid(row=row, column=col, sticky="ew", padx=2, pady=2)
-    
-        for c in range(cols):
-            self.group_frame.grid_columnconfigure(c, weight=1)
+            col_in_row = idx % cols
+            row_start = row * cols
+            num_in_row = min(cols, n - row_start)
+
+            rel_width = 1.0 / num_in_row
+            rel_x = col_in_row * rel_width
+            rel_y = row / rows
+            rel_height = 1.0 / rows
+
+            btn.place(
+                in_=self.group_frame,
+                relx=rel_x,
+                rely=rel_y,
+                relwidth=rel_width,
+                relheight=rel_height
+            )
 
     def switch_group(self, idx):
         if idx == self.current_group:
@@ -214,25 +244,26 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         self.filtered_values = None
         self.current_page = 0
         self._init_buttons()
-    
+
     def update_buttons(self, values_list):
         for i, value in enumerate(values_list):
             if i in self.widgets:
                 btn, _ = self.widgets[i]
-                btn.configure(text=value, command=lambda v=value: self._attach_key_press(v))
+                btn.configure(text=value, command=lambda v=value: self._attach_key_press(v), image=self.value_to_image.get(value))
                 btn.pack(fill="x", pady=2, padx=(self.padding, 0))
                 self.widgets[i][1] = True
             else:
                 btn = customtkinter.CTkButton(
                     self.button_container,
                     text=value,
-                    font=("Segoe UI", 12),
+                    font=self.font,
                     command=lambda v=value: self._attach_key_press(v),
                     height=self.button_height,
                     fg_color=self.button_color,
                     text_color=self.text_color,
                     anchor=self.justify,
-                    hover_color=self.hover_color
+                    hover_color=self.hover_color,
+                    image=self.value_to_image.get(value)
                 )
                 btn.pack(fill="x", pady=2, padx=(self.padding, 0))
                 self.widgets[i] = [btn, True]
@@ -248,10 +279,13 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         self.after(500, self.destroy_popup)
 
     def _withdraw(self):
+        if self.animating:
+            return
         if not self.winfo_exists():
             return
         if self.winfo_viewable() and self.hide_flag:
-            self.withdraw()
+            self._animated_withdraw()
+            return
         self.event_generate("<<Closed>>")
         self.hide_flag = True
 
@@ -328,7 +362,7 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
             self._update_pagination_buttons(filtered=bool(self.filtered_values))
             self.frame.update_idletasks()
             self.frame._parent_canvas.yview_moveto(len(values_to_show) / self.items_per_page)
-    
+
     def destroy_popup(self):
         self.destroy()
         self.disable = True
@@ -342,13 +376,8 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         current_y_pos = self.winfo_y()
         self.x_pos = self.attach.winfo_rootx() if self.x is None else self.x + self.attach.winfo_rootx()
         self.width_new = self.attach.winfo_width() if self.width is None else self.width
-        if self.resize:
-            displayed_items = len(self.filtered_values) if self.filtered_values is not None else len(self.values)
-            if self.pagination:
-                displayed_items = min(displayed_items, self.items_per_page)
-            base_height = 50 if self.pagination else 35
-            items_height = displayed_items * self.button_height
-            self.height_new = items_height + base_height
+        if not self.is_height:
+            self.height_new = self.attach.winfo_toplevel().winfo_height()
         screen_height = self.winfo_screenheight()
         dropdown_bottom = self.attach.winfo_rooty() + self.height_new
         if dropdown_bottom > screen_height:
@@ -360,12 +389,17 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
                 or current_x_pos != self.x_pos
                 or current_y_pos != self.y_pos):
             self.geometry(f"{self.width_new}x{self.height_new}+{self.x_pos}+{self.y_pos}")
-            self.attributes('-alpha', self.alpha)
+            if self.fade_enabled:
+                self.attributes('-alpha', 0)
+            else:
+                self.attributes('-alpha', self.alpha)
             self.update_idletasks()
             if self.pagination:
                 self._update_pagination_buttons(filtered=bool(self.filtered_values))
 
     def _iconify(self):
+        if self.animating:
+            return
         if self.attach.cget("state") == "disabled":
             return
         if self.disable:
@@ -379,10 +413,12 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
             self.place_dropdown()
             self._deiconify()
         else:
-            self.withdraw()
+            self._animated_withdraw()
             self.hide_flag = True
 
     def _attach_key_press(self, k):
+        if self.animating:
+            return
         if hasattr(self, "search_var"):
             self.search_var.set("")
         self.event_generate("<<Selected>>")
@@ -396,11 +432,11 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
             if self.pagination:
                 self.pagination_frame.pack(fill="x", side="bottom")
         self.fade = False
-        self.withdraw()
+        self._animated_withdraw()
         self.hide_flag = True
 
     def live_update(self, string=None):
-        if self.disable or self.fade:
+        if self.disable or self.fade or self.animating:
             return
         self.frame._parent_canvas.yview_moveto(0)
         if string and string.strip() != "":
@@ -432,7 +468,7 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         index = len(self.values)
         if index in self.widgets:
             btn, _ = self.widgets[index]
-            btn.configure(text=value, command=lambda v=value: self._attach_key_press(v))
+            btn.configure(text=value, command=lambda v=value: self._attach_key_press(v), image=self.value_to_image.get(value))
             btn.pack(fill="x", pady=2, padx=(self.padding, 0))
             self.widgets[index][1] = True
         else:
@@ -444,8 +480,9 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
                                           hover_color=self.hover_color,
                                           anchor=self.justify,
                                           command=lambda v=value: self._attach_key_press(v),
-                                          width=0
-                                          **kwargs)
+                                          image=self.value_to_image.get(value),
+                                          width=0,
+                                          *kwargs)
             btn.pack(fill="x", pady=2, padx=(self.padding, 0))
             self.widgets[index] = [btn, True]
         self.values.append(value)
@@ -457,7 +494,14 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
 
     def _deiconify(self):
         if self.all_values:
-            self.deiconify()
+            if self.fade_enabled:
+                if self.animating:
+                    return
+                self.deiconify()
+                self._animate_fade_in()
+            else:
+                self.deiconify()
+                self.attributes('-alpha', self.alpha)
 
     def popup(self, x=None, y=None):
         self.x = x
@@ -472,8 +516,7 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
         if self.old_kwargs == kwargs:
             return
         if "height" in kwargs:
-            self.height = kwargs.pop("height")
-            self.height_new = self.height
+            self.height_new = kwargs.pop("height")
         if "alpha" in kwargs:
             self.alpha = kwargs.pop("alpha")
         if "width" in kwargs:
@@ -515,11 +558,11 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
                     self.groups.append({"name": g[0], "pattern": g[1]})
                 else:
                     raise ValueError(f"groups must be list of [name, pattern], got {g!r}")
-        
+
             self.group_names = [g["name"] for g in self.groups]
             self.group_patterns = []
             included_values = set()
-        
+
             for g in self.groups:
                 pattern = g["pattern"]
                 if pattern == "__OTHERS__":
@@ -529,22 +572,28 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
                     self.group_patterns.append(compiled)
                     matched = [v for v in self.all_values if compiled.search(v)]
                     included_values.update(matched)
-        
+
             self.grouped_values = {}
             for i, pat in enumerate(self.group_patterns):
                 if pat == "__OTHERS__":
                     self.grouped_values[i] = [v for v in self.all_values if v not in included_values]
                 else:
                     self.grouped_values[i] = [v for v in self.all_values if pat.search(v)]
-        
+
             self.current_group = 0
             self.switch_group(self.current_group)
         if "image_values" in kwargs:
-            self.image_values = kwargs.pop("image_values")
-            self.image_values = None if len(self.image_values) != len(self.values) else self.image_values
-            if self.image_values is not None:
-                for i in range(len(self.values)):
-                    self.widgets[i][0].configure(image=self.image_values[i])
+            image_values_arg = kwargs.pop("image_values")
+            self.image_values = image_values_arg
+            self.value_to_image = {}
+
+            if image_values_arg and len(image_values_arg) == len(self.values):
+                for val, img in zip(self.values, image_values_arg):
+                    self.value_to_image[val] = img
+
+            for key, (btn, visible) in self.widgets.items():
+                current_value = btn.cget("text")
+                btn.configure(image=self.value_to_image.get(current_value))
         if "button_color" in kwargs:
             bc = kwargs.pop("button_color")
             for key in self.widgets:
@@ -554,3 +603,74 @@ class CTkScrollableDropdown(customtkinter.CTkToplevel):
                 self.widgets[key][0].configure(**kwargs)
         self.old_kwargs = kwargs
         self.master.update()
+
+    def _animate_fade_in(self):
+        if not self.fade_enabled:
+            self.attributes('-alpha', self.alpha)
+            return
+        if self.animating:
+            return
+        self.animating = True
+        total_frames = max(1, int(self.fps * self.fade_animation_duration))
+        step = float(self.alpha) / total_frames
+        current = 0.0
+        interval = max(1, int(1000 / self.fps))
+        def step_fn(frame, value):
+            new_value = value + step
+            if new_value >= self.alpha or frame >= total_frames - 1:
+                try:
+                    self.attributes('-alpha', self.alpha)
+                finally:
+                    self.animating = False
+                return
+            try:
+                self.attributes('-alpha', new_value)
+            except Exception:
+                pass
+            self.after(interval, lambda: step_fn(frame + 1, new_value))
+        try:
+            self.attributes('-alpha', 0.0)
+        except Exception:
+            pass
+        step_fn(0, current)
+
+    def _animated_withdraw(self):
+        if not self.winfo_exists():
+            return
+        if not self.fade_enabled:
+            if self.winfo_viewable():
+                self.withdraw()
+            self.event_generate("<<Closed>>")
+            self.hide_flag = True
+            return
+        if self.animating:
+            return
+        self.animating = True
+        total_frames = max(1, int(self.fps * self.fade_animation_duration))
+        step = float(self.alpha) / total_frames
+        interval = max(1, int(1000 / self.fps))
+        current_alpha = None
+        try:
+            current_alpha = float(self.attributes('-alpha'))
+        except Exception:
+            current_alpha = self.alpha
+        def step_fn(frame, value):
+            new_value = value - step
+            if new_value <= 0 or frame >= total_frames - 1:
+                try:
+                    self.attributes('-alpha', 0.0)
+                finally:
+                    try:
+                        if self.winfo_viewable():
+                            self.withdraw()
+                    finally:
+                        self.event_generate("<<Closed>>")
+                        self.hide_flag = True
+                        self.animating = False
+                return
+            try:
+                self.attributes('-alpha', new_value)
+            except Exception:
+                pass
+            self.after(interval, lambda: step_fn(frame + 1, new_value))
+        step_fn(0, current_alpha)
